.. include:: ../global.rst

Installation and Configuration
==============================

The preferred way
-----------------

On any system you can install |parso| directly from the Python package index
using pip::

    sudo pip install parso


From git
--------
If you want to install the current development version (master branch)::

    sudo pip install -e git://github.com/davidhalter/parso.git#egg=parso


Manual installation from a downloaded package (not recommended)
---------------------------------------------------------------

If you prefer not to use an automated package installer, you can `download
<https://github.com/davidhalter/parso/archive/master.zip>`__ a current copy of
|parso| and install it manually.

To install it, navigate to the directory containing `setup.py` on your console
and type::

    sudo python setup.py install
